@@ -8,11 +8,6 @@ some defaults required to run django-pages
 from django.conf import settings
 
 
-try:
-    ADMIN_URL = settings.ADMIN_URL
-except AttributeError:
-    ADMIN_URL = 'admin/'
-
 try:
     ADMIN_MEDIA_PREFIX = settings.ADMIN_MEDIA_PREFIX
 except AttributeError:
