@@ -12,7 +12,7 @@ MANAGERS = ADMINS
 DATABASES = {
     'default': {
         'ENGINE': 'django.db.backends.sqlite3',  # Add 'postgresql_psycopg2', 'mysql', 'sqlite3' or 'oracle'.
-        'NAME': 'wysiwyg.db',                      # Or path to database file if using sqlite3.
+        'NAME': 'sample_project/wysiwyg.db',                      # Or path to database file if using sqlite3.
         # The following settings are not used with sqlite3:
         'USER': '',
         'PASSWORD': '',
@@ -52,7 +52,7 @@ USE_L10N = True
 # Example: "/var/www/example.com/media/"
 
 # FILL THIS!
-MEDIA_ROOT = '/home/lukas/torrentsync/Django/django-pages/sample_project/media/'
+MEDIA_ROOT = '/media/sf_D_DRIVE/BTsync/Django/django-pages/sample_project/media/'
 
 # URL that handles the media served from MEDIA_ROOT. Make sure to use a
 # trailing slash.
@@ -102,10 +102,10 @@ MIDDLEWARE_CLASSES = (
     'django_pages.log.middleware.RequestLog',
 )
 
-ROOT_URLCONF = 'urls'
+ROOT_URLCONF = 'sample_project.urls'
 
 # Python dotted path to the WSGI application used by Django's runserver.
-WSGI_APPLICATION = 'wsgi.application'
+WSGI_APPLICATION = 'sample_project.wsgi.application'
 
 TEMPLATE_DIRS = (
     '',
